summaryrefslogtreecommitdiff
path: root/guix/vkraus/packages
diff options
context:
space:
mode:
Diffstat (limited to 'guix/vkraus/packages')
-rw-r--r--guix/vkraus/packages/disfluid.scm (renamed from guix/vkraus/packages/webid-oidc.scm)44
1 files changed, 23 insertions, 21 deletions
diff --git a/guix/vkraus/packages/webid-oidc.scm b/guix/vkraus/packages/disfluid.scm
index 223438b..f372315 100644
--- a/guix/vkraus/packages/webid-oidc.scm
+++ b/guix/vkraus/packages/disfluid.scm
@@ -1,4 +1,4 @@
;; webid-oidc, implementation of the Solid specification
;; Copyright (C) 2020, 2021 Vivien Kraus
;; This program is free software: you can redistribute it and/or modify
@@ -14,7 +14,7 @@
;; You should have received a copy of the GNU Affero General Public License
;; along with this program. If not, see <https://www.gnu.org/licenses/>.
-(define-module (vkraus packages webid-oidc)
+(define-module (vkraus packages disfluid)
#:use-module (guix packages)
#:use-module (guix gexp)
#:use-module ((guix licenses) #:prefix license:)
@@ -33,11 +33,11 @@
#:use-module (gnu packages man)
#:use-module (gnu packages tls))
-(define-public webid-oidc-snapshot
+(define-public disfluid-snapshot
(package
- (name "webid-oidc-snapshot")
+ (name "disfluid-snapshot")
(version "SNAPSHOT")
- (source "./webid-oidc-SNAPSHOT.tar.gz")
+ (source "./disfluid-SNAPSHOT.tar.gz")
(build-system gnu-build-system)
(arguments
'(#:modules ((guix build utils)
@@ -90,13 +90,15 @@
prop-input effective-version))
guile-propagated-inputs))))
(wrap-program
- (format #f "~a/bin/webid-oidc" out)
+ (format #f "~a/bin/disfluid" out)
`("GUILE_LOAD_PATH" ":" = ,mod-paths)
`("GUILE_LOAD_COMPILED_PATH" ":" = ,go-paths))
+ (symlink (format #f "~a/bin/disfluid" out)
+ (format #f "~a/bin/webid-oidc" out))
(for-each
(lambda (program)
(wrap-program
- (format #f "~a/bin/webid-oidc-~a" out program)
+ (format #f "~a/bin/disfluid-~a" out program)
`("GUILE_LOAD_PATH" ":" = ,mod-paths)
`("GUILE_LOAD_COMPILED_PATH" ":" = ,go-paths)))
'(example-app hello))))))))
@@ -121,8 +123,8 @@
("guile-jsonld" ,guile-rdf)
("gnutls" ,gnutls)
("nettle" ,nettle)))
- (synopsis "")
- (description "")
+ (synopsis "Demanding Interoperability to Strengthen the Free (Libre) Web: Introducing Disfluid")
+ (description "Demanding Interoperability to Strengthen the Free (Libre) Web: Introducing Disfluid")
(home-page "https://labo.planete-kraus.eu/webid-oidc.git")
(license license:agpl3+)
(native-search-paths
@@ -130,10 +132,10 @@
(variable "LTDL_LIBRARY_PATH")
(files '("lib")))))))
-(define-public (webid-oidc-release version release-date commit hash)
+(define-public (disfluid-release version release-date commit hash)
(package
- (inherit webid-oidc-snapshot)
- (name "webid-oidc")
+ (inherit disfluid-snapshot)
+ (name "disfluid")
(version version)
(source
(origin
@@ -150,10 +152,10 @@
(lambda _ (format #t "~a~%" ,release-date)))
#t))))))
-(define-public (webid-oidc-htmlize webid-oidc)
+(define-public (disfluid-htmlize disfluid)
(package
- (inherit webid-oidc)
- (name "webid-oidc-html")
+ (inherit disfluid)
+ (name "disfluid-html")
(arguments
'(#:modules ((guix build utils)
(guix build gnu-build-system)
@@ -192,14 +194,14 @@
get-string-all)
#\newline))))
(copy-file (string-append
- "webid-oidc-" version ".tar.gz")
+ "disfluid-" version ".tar.gz")
(string-append
(assoc-ref outputs "out")
- "/share/doc/webid-oidc/webid-oidc.html/complete-corresponding-source.tar.gz"))))))))
- (synopsis "HTML documentation for webid-oidc")
- (description "The manual for webid-oidc is provided as a texinfo
+ "/share/doc/disfluid/disfluid.html/complete-corresponding-source.tar.gz"))))))))
+ (synopsis "HTML documentation for Disfluid")
+ (description "The manual for disfluid is provided as a texinfo
file, which is exported to HTML. Also include the complete
corresponding source, as an AGPL requirement.")))
-(define-public (make-website webid-oidc)
- (file-append (webid-oidc-htmlize webid-oidc) "/share/doc/webid-oidc/webid-oidc.html"))
+(define-public (make-website disfluid)
+ (file-append (disfluid-htmlize disfluid) "/share/doc/disfluid/disfluid.html"))
@@ -1,4 +1,4 @@
-;; webid-oidc, implementation of the Solid specification
+;; disfluid, implementation of the Solid specification
;; Copyright (C) 2020, 2021 Vivien Kraus
;; This program is free software: you can redistribute it and/or modify